@@ -3,8 +3,8 @@
 
 __title__ = "env-alias"
 __author__ = "Nicholas de Jong <contact@nicholasdejong.com>"
-__version__ = '0.3.6'
+__version__ = "0.3.7"
 __license__ = "BSD2"
 
-__logger_default_level__ = 'info'
-__env_alias_generator__ = 'env-alias-generator'
+__logger_default_level__ = "info"
+__env_alias_generator__ = "env-alias-generator"
